==============================
Models Source
==============================

Star
-------------------

.. autoclass:: exorad.models.source.Star
    :members:
    :undoc-members:
    :show-inheritance:

CustomSed
-------------------

.. autoclass:: exorad.models.source.CustomSed
    :members:
    :undoc-members:
    :show-inheritance:

